@@ -69,6 +69,11 @@ from .wrappers import (
 
 core.__load_stage_attributes_from_module__("pdpipe.wrappers")
 
+from .fly import (
+    drop_rows_where,
+    keep_rows_where,
+)
+
 try:
     from . import sklearn_stages
     from .sklearn_stages import (
@@ -106,8 +111,10 @@ except ImportError:
     )
 
 from . import cq
+from . import rq
 from . import cond
 from . import df
+from . import skintegrate
 
 
 from ._version import get_versions
